import type Element from '../nodes/element/Element.cjs';
import IAttr from '../nodes/attr/IAttr.cjs';
import INamedNodeMap from './INamedNodeMap.cjs';
/**
 * NamedNodeMap.
 *
 * Reference:
 * https://developer.mozilla.org/en-US/docs/Web/API/NamedNodeMap.
 */
export default class NamedNodeMap implements INamedNodeMap {
    #private;
    [index: number]: IAttr;
    /**
     * Constructor.
     *
     * @param element Associated element.
     */
    constructor(element: Element);
    /**
     * Returns string.
     *
     * @returns string.
     */
    get [Symbol.toStringTag](): string;
    /**
     * Length.
     *
     * @returns Length.
     */
    get length(): number;
    /**
     * Returns attribute by index.
     *
     * @param index Index.
     */
    item(index: number): IAttr | null;
    /**
     * Returns attribute by name.
     *
     * @param qualifiedName Name.
     * @returns Attribute.
     */
    getNamedItem(qualifiedName: string): IAttr | null;
    /**
     * Returns attribute by name and namespace.
     *
     * @param namespace Namespace.
     * @param localName Local name of the attribute.
     * @returns Attribute.
     */
    getNamedItemNS(namespace: string, localName: string): IAttr | null;
    /**
     * Adds a new attribute node.
     *
     * @param attr Attribute.
     * @returns Replaced attribute.
     */
    setNamedItem(attr: IAttr): IAttr;
    /**
     * Adds a new namespaced attribute node.
     *
     * @param attr Attribute.
     * @returns Replaced attribute.
     */
    setNamedItemNS(attr: IAttr): IAttr;
    /**
     * Removes an attribute.
     *
     * @param qualifiedName Name of the attribute.
     * @returns Removed attribute.
     */
    removeNamedItem(qualifiedName: string): IAttr | null;
    /**
     * Removes a namespaced attribute.
     *
     * @param namespace Namespace.
     * @param localName Local name of the attribute.
     * @returns Removed attribute.
     */
    removeNamedItemNS(namespace: string, localName: string): IAttr | null;
    /**
     * Iterator.
     *
     * @returns Iterator.
     */
    [Symbol.iterator](): Iterator<IAttr>;
}
//# sourceMappingURL=NamedNodeMap.d.ts.map